@@ -14,7 +14,7 @@ use HTML::Entities;
 use Digest::MD5 "md5_base64";      # for making seen content key/index
 #---------------------------------------------------------------------
 use Carp;
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 our $VERBOSITY ||= 0;
 #=====================================================================
 #  METHODS
@@ -844,7 +844,7 @@ sub get_seed {
 
 WWW::Spyder - a simple non-persistent web crawler.
 
-=head1 VERSION 0.19
+=head1 VERSION 0.20
 
 =head1 SYNOPSIS
 
@@ -1136,6 +1136,10 @@ I'd like the thing to be able to parse RTF, PDF, and perhaps even
 resource sections of image files but that isn't on the radar right
 now.
 
+The tests should work differently. Currently they ask for outside
+resources without checking if there is either an open way to do it or
+if the user approves of it. Bad form all around.
+
 =head1 TO DOABLE BY 1.0
 
 Add 2-4 sample scripts that are a bit more useful.
